AppBarConfig class

Configuration for the app bar.

Constructors

AppBarConfig({String? title, TextStyle? titleStyle, Color? backgroundColor, double? elevation = 0, Widget? customBackIcon, bool centerTitle = true, bool automaticallyImplyLeading = true, bool showBackButton = true})
Creates an app bar configuration.
const

Properties

automaticallyImplyLeading → bool
Whether to automatically show leading widget.
final
backgroundColor → Color?
Background color of the app bar.
final
centerTitle → bool
Whether to center the title.
final
customBackIcon → Widget?
Custom back button widget.
final
elevation → double?
Elevation of the app bar.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBackButton → bool
Whether to show the back button.
final
title → String?
Title text for the app bar.
final
titleStyle → TextStyle?
Text style for the title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited