CameraSettings class

Camera-specific configuration settings.

Constructors

CameraSettings({ResolutionPreset? resolutionPreset = ResolutionPreset.high, bool? enableAudio = false, ImageFormatGroup? imageFormatGroup, int cameraInitDelay = 2500})
Creates camera settings.
const

Properties

cameraInitDelay → int
Delay in milliseconds before starting image stream after camera initialization. Default is 2500ms to ensure camera is fully ready.
final
enableAudio → bool?
Whether to enable audio recording.
final
hashCode → int
The hash code for this object.
no setterinherited
imageFormatGroup → ImageFormatGroup?
Image format group for camera output.
final
resolutionPreset → ResolutionPreset?
Camera resolution preset.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited