LivenessCheckMessages class

Customizable text messages for the liveness check screen.

Constructors

LivenessCheckMessages({String title = 'Liveness Check', String initializingCamera = 'Initializing camera...', String noFaceDetected = 'No face detected. Please position your face in the circle.', String multipleFacesDetected = 'Multiple faces detected. Only one person allowed.', String moveCloserToCamera = 'Move closer to camera or hold device steady.', String holdStill = 'Hold still. Face features not clear.', String imageTooBlurry = 'Image too blurry. Hold device steady.', String poorLighting = 'Poor lighting conditions.', String livenessCheckPassed = 'Liveness check passed! Taking photo...', String takingPhoto = 'Taking photo...', String failedToCapture = 'Failed to capture photo', String cameraPermissionDenied = 'Camera permission denied', String failedToInitializeCamera = 'Failed to initialize camera', String eyesClosed = 'Please open your eyes.', String maskDetected = 'Please remove your mask.', String spoofingDetected = 'Spoofing detected. Please use a real face.', String tryAgainButtonText = 'Try Again', PermissionDialogConfig permissionDialogConfig = const PermissionDialogConfig()})
Creates liveness check messages.
const

Properties

cameraPermissionDenied → String
Message shown when camera permission is denied.
final
eyesClosed → String
Message shown when eyes are closed.
final
failedToCapture → String
Message shown when photo capture fails.
final
failedToInitializeCamera → String
Message shown when camera initialization fails.
final
hashCode → int
The hash code for this object.
no setterinherited
holdStill → String
Message shown when user needs to hold still.
final
imageTooBlurry → String
Message shown when image is too blurry.
final
initializingCamera → String
Message shown while initializing camera.
final
livenessCheckPassed → String
Message shown when liveness check passes.
final
maskDetected → String
Message shown when mask is detected or nose/mouth not visible.
final
moveCloserToCamera → String
Message shown when user needs to move closer.
final
multipleFacesDetected → String
Message shown when multiple faces are detected.
final
noFaceDetected → String
Message shown when no face is detected.
final
permissionDialogConfig → PermissionDialogConfig
Configuration for the permission dialog.
final
poorLighting → String
Message shown when lighting is poor.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spoofingDetected → String
Message shown when spoofing is detected (fake face).
final
takingPhoto → String
Message shown while taking photo.
final
title → String
Title of the screen.
final
tryAgainButtonText → String
Text for the try again button.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited