errorMessageMargin property
Margin/spacing between error message and the camera circle (in pixels). Controls how far above the circle the error message appears. Default: 80 pixels.
Implementation
final double errorMessageMargin;
Margin/spacing between error message and the camera circle (in pixels). Controls how far above the circle the error message appears. Default: 80 pixels.
final double errorMessageMargin;