errorMessageTopPadding property
Top padding/spacing above the error message text (in pixels). Adds extra space between the container border and the text. Default: 0 pixels.
Implementation
final double errorMessageTopPadding;
Top padding/spacing above the error message text (in pixels). Adds extra space between the container border and the text. Default: 0 pixels.
final double errorMessageTopPadding;