DashedCirclePainter class

A custom painter that draws a dashed circular border.

This painter creates a circular border with evenly spaced dashes around the circumference. The dashes are automatically adjusted to fit perfectly around the circle, ensuring a symmetrical appearance.

Example:

CustomPaint(
  size: Size(300, 300),
  painter: DashedCirclePainter(
    color: Colors.blue,
    strokeWidth: 4.0,
    dashLength: 10.0,
    dashGap: 8.0,
  ),
)
Inheritance

Constructors

DashedCirclePainter({required Color color, required double strokeWidth, required double dashLength, required double dashGap})
Creates a dashed circle painter.

Properties

color → Color
The color of the dashed border.
final
dashGap → double
The gap between each dash segment.
final
dashLength → double
The length of each dash segment.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder → SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
strokeWidth → double
The width of the stroke (border thickness).
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) → bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Paints the dashed circle on the canvas.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CustomPainter oldDelegate) → bool
Determines whether the painter should repaint.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited